import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React from 'react';

import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  className: 'header',
  enableBars: false,
  barsColor: colors.theme.headerTextIcon,
  text: 'Área do Professor',
  disableText: true,
  arrowsColor: colors.theme.iconHeader,
  disableArrow: true,
  onClickArrow: () => {
    alert('clicou');
  },
  onClickBars: () => {
    alert('clicou');
  },
};

type HeaderProps = {
  className?: string;
  enableBars?: boolean;
  barsColor?: string;
  text?: string;
  disableText?: boolean;
  arrowsColor?: string;
  disableArrow?: boolean;
  onClickArrow?: () => void;
  onClickBars?: () => void;
} & typeof defaultProps;

function Header(props: HeaderProps) {
  const {
    className,
    enableBars,
    barsColor,
    text,
    disableText,
    arrowsColor,
    disableArrow,
    onClickArrow,
    onClickBars,
  } = props;

  const styles = {
    header: {
      width: '100%',
      height: '6.25em',
      background: colors.theme.blue,
      display: 'flex',
      justifyContent: 'space-around',
      alignItems: 'center',
      alignContent: 'center',
      borderRadius: '0px 0px 10px 10px',
    },
    text: {
      color: colors.theme.iconHeader,
      fontStyle: 'roboto',
      fontWeight: 'bold',
      fontSize: '1.5em',
      position: 'absolute' as const,
      marginBottom: '0em',
    },
    bars: {
      color: `${barsColor}`,
      height: '1.625em',
      marginLeft: 'auto',
      paddingRight: '5%',
      width: '1.875em',
    },
    arrowLeft: {
      color: `${arrowsColor}`,
      height: '1.875em',
      marginRight: 'auto',
      paddingLeft: '5%',
      width: '1.875em',
    },
  };

  return (
    <div className={className} style={styles.header}>
      {disableArrow && (
        <FontAwesomeIcon
          icon={fontawesome.icons.faArrowLeft}
          style={styles.arrowLeft}
          onClick={onClickArrow}
        />
      )}
      {disableText && <h1 style={styles.text}>{text}</h1>}
      {enableBars && (
        <FontAwesomeIcon
          icon={fontawesome.icons.faBars}
          style={styles.bars}
          onClick={onClickBars}
        />
      )}
    </div>
  );
}

Header.defaultProps = defaultProps;

export default Header;
